@@ -14,8 +14,14 @@ module AutoprefixerRails
 
   # Add Autoprefixer for Sprockets environment in `assets`.
   # You can specify `browsers` actual in your project.
-  def self.install(assets, params = { }, opts = { })
-    Sprockets.new( processor(params) ).install(assets, opts)
+  def self.install(assets, params = { })
+    Sprockets.register_processor(processor(params))
+    Sprockets.install(assets)
+  end
+
+  # Disable installed Autoprefixer
+  def self.uninstall(assets)
+    Sprockets.uninstall(assets)
   end
 
   # Cache processor instances
