@@ -11,11 +11,12 @@ describe AutoprefixerRails do
   end
 
   it "process CSS for selected browsers" do
-    result = AutoprefixerRails.process(@css, browsers: ['opera 12'])
+    css = "a {\n    tab-size: 2\n}"
+    result = AutoprefixerRails.process(css, browsers: ['opera 12'])
     expect(result.css).to eq "a {\n" +
-                             "    -o-transition: all 1s;\n" +
-                             "       transition: all 1s\n" +
-                             "}\n"
+                             "    -o-tab-size: 2;\n" +
+                             "       tab-size: 2\n" +
+                             "}"
   end
 
   it "generates source map" do
@@ -64,11 +65,11 @@ describe AutoprefixerRails do
     css    = 'a{background:linear-gradient(top,white,black)}'
     result = AutoprefixerRails.process(css)
     expect(result.warnings).to eq(['<css input>:1:3: Gradient has outdated ' +
-      'direction syntax. New syntax is like "to left" instead of "right".'])
+      'direction syntax. New syntax is like `to left` instead of `right`.'])
   end
 
   context 'Sprockets' do
-    before :all do
+    before :each do
       @assets = Sprockets::Environment.new
       @assets.append_path(@dir.join('app/app/assets/stylesheets'))
       AutoprefixerRails.install(@assets, browsers: ['chrome 25'])
@@ -77,13 +78,21 @@ describe AutoprefixerRails do
     it "integrates with Sprockets" do
       css = @assets['test.css'].to_s
       expect(css).to eq "a {\n" +
-                        "    -webkit-transition: all 1s;\n" +
-                        "            transition: all 1s\n" +
+                        "    -webkit-mask: none;\n" +
+                        "            mask: none\n" +
                         "}\n"
     end
 
     it "shows file name from Sprockets", not_jruby: true do
-      expect { @assets['wrong.css'] }.to raise_error(/wrong.css:/)
+      expect { @assets['wrong.css'] }.to raise_error(/wrong/)
+    end
+
+    it "supports disabling", not_jruby: true do
+      AutoprefixerRails.uninstall(@assets)
+      css = @assets['test.css'].to_s
+      expect(css).to eq "a {\n" +
+                        "    mask: none\n" +
+                        "}\n"
     end
 
   end
