@@ -10,7 +10,16 @@ describe CssController, type: :controller do
     get :test, file: 'sass'
     expect(response).to be_success
     clear_css = response.body.gsub("\n", " ").squeeze(" ").strip
-    expect(clear_css).to eq "a { -webkit-transition: all 1s; transition: all 1s; }"
+    expect(clear_css).to eq "a { -webkit-mask: none; mask: none; }"
+  end
+
+  if Sprockets::Context.instance_methods.include?(:evaluate)
+    it 'supports evaluate' do
+      get :test, file: 'evaluate'
+      expect(response).to be_success
+      clear_css = response.body.gsub("\n", ' ').squeeze(' ').strip
+      expect(clear_css).to eq 'a { -webkit-mask: none; mask: none }'
+    end
   end
 end
 
